"""Main entry point for running VenomLearn as a module.

This file allows the package to be executed directly using:
python -m VenomLearn
"""

from VenomLearn.main import main

if __name__ == "__main__":
    main()